@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 """Helper functions for the manager classes"""
 
+import time
 from copy import deepcopy
 from pathlib import Path
 from urllib.parse import urljoin
@@ -8,7 +9,11 @@ from urllib.parse import urljoin
 import requests
 
 from ..constants import DEFAULT_SOURCE_DICT
-from ..errors import InvalidInstanceUrlError, InvalidSourceError
+from ..errors import InvalidInstanceUrlError, InvalidSourceError, RequestFailed
+
+
+def current_milli_time():
+    return round(time.time() * 1000)
 
 
 def _new_toc(toc, dtype, filename, metadata=None, source_dict=None):
@@ -26,20 +31,24 @@ def _new_toc(toc, dtype, filename, metadata=None, source_dict=None):
             if not isinstance(value, str):
                 raise InvalidSourceError("Source values must be strings")
 
-    extension = Path(filename).suffix.replace(".", "")
+    extension = str(Path(filename).suffix).replace(".", "")
+    if extension == "":
+        raise ValueError("You need to provide a file extension")
+
     append_dict = {
         "source": source_dict,
         extension: {"filename": f"spectra/{dtype}/{filename}"},
     }
+    toc_copy["$modificationDate"] = current_milli_time()
     if isinstance(metadata, dict):
         for key, value in metadata.items():
             append_dict[key] = value
 
     try:
-        toc_copy["$content"]["spectra"][type].append(append_dict)
+        toc_copy["$content"]["spectra"][dtype].append(append_dict)
     except KeyError:
         # first entry
-        toc_copy["$content"]["spectra"][type] = [append_dict]
+        toc_copy["$content"]["spectra"][dtype] = [append_dict]
     return toc_copy
 
 
@@ -71,3 +80,12 @@ def sanitize_instance_url(url: str) -> str:
         raise InvalidInstanceUrlError("Testing the instance URL failed") from execpt
 
     return url
+
+
+def test_upload(url, requester):
+    response = requester._make_request("GET", url)  # pylint:disable=protected-access
+    if not response.status_code == 200:
+        raise RequestFailed(
+            "Unexpected error occured in the upload process.\
+             Check the ELN for data corruption!"
+        )
